# Changelog

### 0.2.1 (2019-12-03)

Fix packaging errors

## 0.2 (2019-11-29)

* Ingest JSON-LD (compressed as zip)
* Ingest Excel BOM
* Output Pandas CSV with format based on [Federal LCA-Commons Elementary Flow Mapping](https://github.com/USEPA/Federal-LCA-Commons-Elementary-Flow-List/blob/master/format%20specs/FlowMapping.md)

### 0.1.1 (2019-10-21)

Bugfix release for data clobbering on export

## 0.1 (2019-10-21)

First public release
